[evolution-data-server/rbradford-async-rename: 2/2] ebook & edataserverui: Use _async suffix rather than _ex suffix



commit 82d7550efb83aafc8f5201a32b3bcdc2ae53f3ee
Author: Rob Bradford <rob linux intel com>
Date:   Sun Aug 1 10:40:58 2010 +0100

    ebook & edataserverui: Use _async suffix rather than _ex suffix

 addressbook/libebook/e-book.c              |  218 ++++++++++++++--------------
 addressbook/libebook/e-book.h              |  126 ++++++++--------
 addressbook/tests/ebook/ebook-test-utils.c |   40 +++---
 addressbook/tests/ebook/test-ebook-async.c |    6 +-
 libedataserverui/e-book-auth-util.c        |   18 +-
 libedataserverui/e-book-auth-util.h        |    2 +-
 libedataserverui/e-name-selector-dialog.c  |    2 +-
 libedataserverui/e-name-selector-entry.c   |    2 +-
 libedataserverui/e-name-selector.c         |    2 +-
 9 files changed, 208 insertions(+), 208 deletions(-)
---
diff --git a/addressbook/libebook/e-book.c b/addressbook/libebook/e-book.c
index c2cd5c8..998b0af 100644
--- a/addressbook/libebook/e-book.c
+++ b/addressbook/libebook/e-book.c
@@ -24,10 +24,10 @@
  * SECTION:e-book
  *
  * The old asynchronous API was deprecated since 3.0 and is replaced with
- * their equivalents with an _ex suffix, which has a detailed #GError
+ * their an equivalent version which has a detailed #GError
  * structure in the asynchronous callback, instead of a status code only.
  *
- * As an example, e_book_async_open() is replaced by e_book_async_open_ex().
+ * As an example, e_book_async_open() is replaced by e_book_open_async().
  */
 
 #include <config.h>
@@ -357,7 +357,7 @@ add_contact_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
 	GError *err = NULL, *error = NULL;
 	gchar *uid = NULL;
 	AsyncData *data = user_data;
-	EBookIdExCallback excb = data->excallback;
+	EBookIdAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookIdCallback cb = data->callback;
 	#endif
@@ -400,7 +400,7 @@ add_contact_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  *
  * Returns: %TRUE if the operation was started, %FALSE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_add_contact_ex() instead.
+ * Deprecated: 3.0: Use e_book_add_contact_async() instead.
  **/
 gboolean
 e_book_async_add_contact (EBook                 *book,
@@ -431,7 +431,7 @@ e_book_async_add_contact (EBook                 *book,
 #endif
 
 /**
- * e_book_async_add_contact_ex:
+ * e_book_add_contact_async:
  * @book: an #EBook
  * @contact: an #EContact
  * @cb: function to call when the operation finishes
@@ -444,10 +444,10 @@ e_book_async_add_contact (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_add_contact_ex (EBook              *book,
-			     EContact           *contact,
-			     EBookIdExCallback   cb,
-			     gpointer            closure)
+e_book_add_contact_async (EBook                *book,
+			  EContact             *contact,
+			  EBookIdAsyncCallback  cb,
+			  gpointer              closure)
 {
 	gchar *vcard;
 	AsyncData *data;
@@ -505,7 +505,7 @@ modify_contact_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data
 {
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookExCallback excb = data->excallback;
+	EBookAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback cb = data->callback;
 	#endif
@@ -542,7 +542,7 @@ modify_contact_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data
  *
  * Returns: %TRUE if the operation was started, %FALSE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_commit_contact_ex() instead.
+ * Deprecated: 3.0: Use e_book_commit_contact_async() instead.
  **/
 guint
 e_book_async_commit_contact (EBook                 *book,
@@ -573,7 +573,7 @@ e_book_async_commit_contact (EBook                 *book,
 #endif
 
 /**
- * e_book_async_commit_contact_ex:
+ * e_book_commit_contact_async:
  * @book: an #EBook
  * @contact: an #EContact
  * @cb: function to call when the operation finishes
@@ -587,10 +587,10 @@ e_book_async_commit_contact (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_commit_contact_ex (EBook                 *book,
-                                EContact              *contact,
-                                EBookExCallback        cb,
-                                gpointer               closure)
+e_book_commit_contact_async (EBook              *book,
+			     EContact           *contact,
+			     EBookAsyncCallback  cb,
+			     gpointer            closure)
 {
 	gchar *vcard;
 	AsyncData *data;
@@ -654,7 +654,7 @@ get_required_fields_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user
 	gchar **fields = NULL;
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookEListExCallback excb = data->excallback;
+	EBookEListAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookEListCallback cb = data->callback;
 	#endif
@@ -694,12 +694,12 @@ get_required_fields_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user
  *
  * Returns: %TRUE if the operation was started, %FALSE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_get_required_fields_ex() instead.
+ * Deprecated: 3.0: Use e_book_get_required_fields_async() instead.
  **/
 guint
 e_book_async_get_required_fields (EBook              *book,
-				   EBookEListCallback  cb,
-				   gpointer            closure)
+				  EBookEListCallback  cb,
+				  gpointer            closure)
 {
 	AsyncData *data;
 
@@ -718,7 +718,7 @@ e_book_async_get_required_fields (EBook              *book,
 #endif
 
 /**
- * e_book_async_get_required_fields_ex:
+ * e_book_get_required_fields_async:
  * @book: an #EBook
  * @cb: function to call when the operation finishes
  * @closure: data to pass to callback function
@@ -731,9 +731,9 @@ e_book_async_get_required_fields (EBook              *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_get_required_fields_ex (EBook               *book,
-				     EBookEListExCallback cb,
-				     gpointer             closure)
+e_book_get_required_fields_async (EBook                   *book,
+				  EBookEListAsyncCallback  cb,
+				  gpointer                 closure)
 {
 	AsyncData *data;
 
@@ -791,7 +791,7 @@ get_supported_fields_reply (GObject *gdbus_book, GAsyncResult *res, gpointer use
 	gchar **fields = NULL;
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookEListExCallback excb = data->excallback;
+	EBookEListAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookEListCallback cb = data->callback;
 	#endif
@@ -832,7 +832,7 @@ get_supported_fields_reply (GObject *gdbus_book, GAsyncResult *res, gpointer use
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_get_supported_fields_ex() instead.
+ * Deprecated: 3.0: Use e_book_get_supported_fields_async() instead.
  **/
 guint
 e_book_async_get_supported_fields (EBook              *book,
@@ -856,7 +856,7 @@ e_book_async_get_supported_fields (EBook              *book,
 #endif
 
 /**
- * e_book_async_get_supported_fields_ex:
+ * e_book_get_supported_fields_async:
  * @book: an #EBook
  * @cb: function to call when the operation finishes
  * @closure: data to pass to callback function
@@ -870,9 +870,9 @@ e_book_async_get_supported_fields (EBook              *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_get_supported_fields_ex (EBook               *book,
-				      EBookEListExCallback cb,
-				      gpointer             closure)
+e_book_get_supported_fields_async (EBook                   *book,
+				   EBookEListAsyncCallback  cb,
+				   gpointer                 closure)
 {
 	AsyncData *data;
 
@@ -929,7 +929,7 @@ get_supported_auth_methods_reply (GObject *gdbus_book, GAsyncResult *res, gpoint
 	gchar **methods = NULL;
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookEListExCallback excb = data->excallback;
+	EBookEListAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookEListCallback cb = data->callback;
 	#endif
@@ -969,7 +969,7 @@ get_supported_auth_methods_reply (GObject *gdbus_book, GAsyncResult *res, gpoint
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_get_supported_auth_methods_ex() instead.
+ * Deprecated: 3.0: Use e_book_get_supported_auth_methods_async() instead.
  **/
 guint
 e_book_async_get_supported_auth_methods (EBook              *book,
@@ -993,7 +993,7 @@ e_book_async_get_supported_auth_methods (EBook              *book,
 #endif
 
 /**
- * e_book_async_get_supported_auth_methods_ex:
+ * e_book_get_supported_auth_methods_async:
  * @book: an #EBook
  * @cb: function to call when the operation finishes
  * @closure: data to pass to callback function
@@ -1006,9 +1006,9 @@ e_book_async_get_supported_auth_methods (EBook              *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_get_supported_auth_methods_ex (EBook               *book,
-					    EBookEListExCallback cb,
-					    gpointer             closure)
+e_book_get_supported_auth_methods_async (EBook                   *book,
+					 EBookEListAsyncCallback  cb,
+					 gpointer                 closure)
 {
 	AsyncData *data;
 
@@ -1061,7 +1061,7 @@ authenticate_user_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_d
 {
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookExCallback excb = data->excallback;
+	EBookAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback cb = data->callback;
 	#endif
@@ -1101,7 +1101,7 @@ authenticate_user_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_d
  *
  * Returns: %FALSE if successful, %TRUE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_authenticate_user_ex() instead.
+ * Deprecated: 3.0: Use e_book_authenticate_user_async() instead.
  **/
 guint
 e_book_async_authenticate_user (EBook                 *book,
@@ -1131,7 +1131,7 @@ e_book_async_authenticate_user (EBook                 *book,
 #endif
 
 /**
- * e_book_async_authenticate_user_ex:
+ * e_book_authenticate_user_async:
  * @book: an #EBook
  * @user: user name
  * @passwd: password
@@ -1149,12 +1149,12 @@ e_book_async_authenticate_user (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_authenticate_user_ex (EBook                 *book,
-				   const gchar           *user,
-				   const gchar           *passwd,
-				   const gchar           *auth_method,
-				   EBookExCallback        cb,
-				   gpointer               closure)
+e_book_authenticate_user_async (EBook              *book,
+				const gchar        *user,
+				const gchar        *passwd,
+				const gchar        *auth_method,
+				EBookAsyncCallback  cb,
+				gpointer            closure)
 {
 	AsyncData *data;
 
@@ -1214,7 +1214,7 @@ get_contact_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
 	gchar *vcard = NULL;
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookContactExCallback excb = data->excallback;
+	EBookContactAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookContactCallback cb = data->callback;
 	#endif
@@ -1254,7 +1254,7 @@ get_contact_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  *
  * Returns: %FALSE if successful, %TRUE otherwise
  *
- * Deprecated: 3.0: Use e_book_async_get_contact_ex() instead.
+ * Deprecated: 3.0: Use e_book_get_contact_async() instead.
  **/
 guint
 e_book_async_get_contact (EBook                 *book,
@@ -1280,7 +1280,7 @@ e_book_async_get_contact (EBook                 *book,
 #endif
 
 /**
- * e_book_async_get_contact_ex:
+ * e_book_get_contact_async:
  * @book: an #EBook
  * @id: a unique string ID specifying the contact
  * @cb: function to call when operation finishes
@@ -1293,10 +1293,10 @@ e_book_async_get_contact (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_get_contact_ex (EBook                 *book,
-			     const gchar           *id,
-			     EBookContactExCallback cb,
-			     gpointer               closure)
+e_book_get_contact_async (EBook                     *book,
+			  const gchar               *id,
+			  EBookContactAsyncCallback  cb,
+			  gpointer                   closure)
 {
 	AsyncData *data;
 
@@ -1349,7 +1349,7 @@ remove_contact_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data
 {
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookExCallback excb = data->excallback;
+	EBookAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback cb = data->callback;
 	#endif
@@ -1418,7 +1418,7 @@ e_book_remove_contacts (EBook    *book,
  *
  * Returns: %TRUE if successful, %FALSE otherwise
  *
- * Deprecated: 3.0: Use e_book_async_remove_contact_ex() instead.
+ * Deprecated: 3.0: Use e_book_remove_contact_async() instead.
  **/
 guint
 e_book_async_remove_contact (EBook                 *book,
@@ -1448,7 +1448,7 @@ e_book_async_remove_contact (EBook                 *book,
 #endif
 
 /**
- * e_book_async_remove_contact_ex:
+ * e_book_remove_contact_async:
  * @book: an #EBook
  * @contact: an #EContact
  * @cb: a function to call when the operation finishes
@@ -1461,10 +1461,10 @@ e_book_async_remove_contact (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_remove_contact_ex (EBook                 *book,
-                                EContact              *contact,
-                                EBookExCallback        cb,
-                                gpointer               closure)
+e_book_remove_contact_async (EBook              *book,
+			     EContact           *contact,
+			     EBookAsyncCallback  cb,
+			     gpointer            closure)
 {
 	AsyncData *data;
 	const gchar *l[2];
@@ -1491,7 +1491,7 @@ remove_contact_by_id_reply (GObject *gdbus_book, GAsyncResult *res, gpointer use
 {
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookExCallback excb = data->excallback;
+	EBookAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback cb = data->callback;
 	#endif
@@ -1526,7 +1526,7 @@ remove_contact_by_id_reply (GObject *gdbus_book, GAsyncResult *res, gpointer use
  *
  * Returns: %TRUE if successful, %FALSE otherwise
  *
- * Deprecated: 3.0: Use e_book_async_remove_contact_by_id_ex() instead.
+ * Deprecated: 3.0: Use e_book_remove_contact_by_id_async() instead.
  **/
 guint
 e_book_async_remove_contact_by_id (EBook                 *book,
@@ -1556,7 +1556,7 @@ e_book_async_remove_contact_by_id (EBook                 *book,
 #endif
 
 /**
- * e_book_async_remove_contact_by_id_ex:
+ * e_book_remove_contact_by_id_async:
  * @book: an #EBook
  * @id: a unique ID string specifying the contact
  * @cb: a function to call when the operation finishes
@@ -1569,10 +1569,10 @@ e_book_async_remove_contact_by_id (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_remove_contact_by_id_ex (EBook                 *book,
-				      const gchar           *id,
-				      EBookExCallback        cb,
-				      gpointer               closure)
+e_book_remove_contact_by_id_async (EBook              *book,
+				   const gchar        *id,
+				   EBookAsyncCallback  cb,
+				   gpointer            closure)
 {
 	AsyncData *data;
 	const gchar *l[2];
@@ -1599,7 +1599,7 @@ remove_contacts_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_dat
 {
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookExCallback excb = data->excallback;
+	EBookAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback cb = data->callback;
 	#endif
@@ -1637,7 +1637,7 @@ remove_contacts_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_dat
  *
  * Returns: %TRUE if successful, %FALSE otherwise
  *
- * Deprecated: 3.0: Use e_book_async_remove_contacts_ex() instead.
+ * Deprecated: 3.0: Use e_book_remove_contacts_async() instead.
  **/
 guint
 e_book_async_remove_contacts (EBook                 *book,
@@ -1673,7 +1673,7 @@ e_book_async_remove_contacts (EBook                 *book,
 #endif
 
 /**
- * e_book_async_remove_contacts_ex:
+ * e_book_remove_contacts_async:
  * @book: an #EBook
  * @ids: a #GList of const gchar *id's
  * @cb: a function to call when the operation finishes
@@ -1689,10 +1689,10 @@ e_book_async_remove_contacts (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_remove_contacts_ex (EBook                 *book,
-                                 GList                 *ids,
-                                 EBookExCallback        cb,
-                                 gpointer               closure)
+e_book_remove_contacts_async (EBook              *book,
+			      GList              *ids,
+			      EBookAsyncCallback  cb,
+			      gpointer            closure)
 {
 	AsyncData *data;
 	gchar **l;
@@ -1789,7 +1789,7 @@ get_book_view_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
 	EBookView *view = NULL;
-	EBookBookViewExCallback excb = data->excallback;
+	EBookBookViewAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookBookViewCallback cb = data->callback;
 	#endif
@@ -1840,7 +1840,7 @@ get_book_view_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  *
  * Returns: %FALSE if successful, %TRUE otherwise
  *
- * Deprecated: 3.0: Use e_book_async_get_book_view_ex() instead.
+ * Deprecated: 3.0: Use e_book_get_book_view_async() instead.
  **/
 guint
 e_book_async_get_book_view (EBook                 *book,
@@ -1872,7 +1872,7 @@ e_book_async_get_book_view (EBook                 *book,
 #endif
 
 /**
- * e_book_async_get_book_view_ex:
+ * e_book_get_book_view_async:
  * @book: an #EBook
  * @query: an #EBookQuery
  * @requested_fields: a #GList containing the names of fields to return, or NULL for all
@@ -1888,12 +1888,12 @@ e_book_async_get_book_view (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_get_book_view_ex (EBook                  *book,
-			       EBookQuery             *query,
-			       GList                  *requested_fields,
-			       gint                    max_results,
-			       EBookBookViewExCallback cb,
-			       gpointer                closure)
+e_book_get_book_view_async (EBook                      *book,
+			    EBookQuery                 *query,
+			    GList                      *requested_fields,
+			    gint                        max_results,
+			    EBookBookViewAsyncCallback  cb,
+			    gpointer                    closure)
 {
 	AsyncData *data;
 	gchar *sexp;
@@ -1968,7 +1968,7 @@ get_contacts_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
 	GList *list = NULL;
-	EBookListExCallback excb = data->excallback;
+	EBookListAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookListCallback cb = data->callback;
 	#endif
@@ -2016,7 +2016,7 @@ get_contacts_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  *
  * Returns: %FALSE on success, %TRUE otherwise
  *
- * Deprecated: 3.0: Use e_book_async_get_contacts_ex() instead.
+ * Deprecated: 3.0: Use e_book_get_contacts_async() instead.
  **/
 guint
 e_book_async_get_contacts (EBook             *book,
@@ -2047,7 +2047,7 @@ e_book_async_get_contacts (EBook             *book,
 #endif
 
 /**
- * e_book_async_get_contacts_ex:
+ * e_book_get_contacts_async:
  * @book: an #EBook
  * @query: an #EBookQuery
  * @cb: a function to call when the operation finishes
@@ -2060,10 +2060,10 @@ e_book_async_get_contacts (EBook             *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_get_contacts_ex (EBook              *book,
-			      EBookQuery         *query,
-			      EBookListExCallback cb,
-			      gpointer            closure)
+e_book_get_contacts_async (EBook                  *book,
+			   EBookQuery             *query,
+			   EBookListAsyncCallback  cb,
+			   gpointer                closure)
 {
 	AsyncData *data;
 	gchar *sexp;
@@ -2160,7 +2160,7 @@ get_changes_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
 	GVariant *var_changes = NULL;
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookListExCallback excb = data->excallback;
+	EBookListAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookListCallback cb = data->callback;
 	#endif
@@ -2203,7 +2203,7 @@ get_changes_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  *
  * Returns: TRUE on success, FALSE otherwise
  *
- * Deprecated: 3.0: Use e_book_async_get_changes_ex() instead.
+ * Deprecated: 3.0: Use e_book_get_changes_async() instead.
  */
 guint
 e_book_async_get_changes (EBook             *book,
@@ -2228,7 +2228,7 @@ e_book_async_get_changes (EBook             *book,
 #endif
 
 /**
- * e_book_async_get_changes_ex:
+ * e_book_get_changes_async:
  * @book: an #EBook
  * @changeid:  the change ID
  * @cb: function to call when operation finishes
@@ -2242,10 +2242,10 @@ e_book_async_get_changes (EBook             *book,
  * Since: 3.0
  */
 gboolean
-e_book_async_get_changes_ex (EBook              *book,
-			     const gchar        *changeid,
-			     EBookListExCallback cb,
-			     gpointer            closure)
+e_book_get_changes_async (EBook                  *book,
+			  const gchar            *changeid,
+			  EBookListAsyncCallback  cb,
+			  gpointer                closure)
 {
 	AsyncData *data;
 
@@ -2364,7 +2364,7 @@ open_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
 {
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookExCallback excb = data->excallback;
+	EBookAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback cb = data->callback;
 	#endif
@@ -2402,7 +2402,7 @@ open_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  *
  * Returns: %FALSE if successful, %TRUE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_open_ex() instead.
+ * Deprecated: 3.0: Use e_book_open_async() instead.
  **/
 guint
 e_book_async_open (EBook                 *book,
@@ -2427,7 +2427,7 @@ e_book_async_open (EBook                 *book,
 #endif
 
 /**
- * e_book_async_open_ex:
+ * e_book_open_async:
  * @book: an #EBook
  * @only_if_exists: if %TRUE, fail if this book doesn't already exist, otherwise create it first
  * @open_response: a function to call when the operation finishes
@@ -2441,10 +2441,10 @@ e_book_async_open (EBook                 *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_open_ex (EBook                 *book,
-		      gboolean               only_if_exists,
-		      EBookExCallback        cb,
-		      gpointer               closure)
+e_book_open_async (EBook              *book,
+		   gboolean            only_if_exists,
+		   EBookAsyncCallback  cb,
+		   gpointer            closure)
 {
 	AsyncData *data;
 
@@ -2490,7 +2490,7 @@ remove_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
 {
 	GError *err = NULL, *error = NULL;
 	AsyncData *data = user_data;
-	EBookExCallback excb = data->excallback;
+	EBookAsyncCallback excb = data->excallback;
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback cb = data->callback;
 	#endif
@@ -2525,7 +2525,7 @@ remove_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  *
  * Returns: %FALSE if successful, %TRUE otherwise.
  *
- * Deprecated: 3.0: Use e_book_async_remove_ex() instead.
+ * Deprecated: 3.0: Use e_book_remove_async() instead.
  **/
 guint
 e_book_async_remove (EBook   *book,
@@ -2549,7 +2549,7 @@ e_book_async_remove (EBook   *book,
 #endif
 
 /**
- * e_book_async_remove_ex:
+ * e_book_remove_async:
  * @book: an #EBook
  * @cb: a function to call when the operation finishes
  * @closure: data to pass to callback function
@@ -2562,9 +2562,9 @@ e_book_async_remove (EBook   *book,
  * Since: 3.0
  **/
 gboolean
-e_book_async_remove_ex (EBook   *book,
-                        EBookExCallback cb,
-                        gpointer closure)
+e_book_remove_async (EBook              *book,
+		     EBookAsyncCallback  cb,
+		     gpointer            closure)
 {
 	AsyncData *data;
 
diff --git a/addressbook/libebook/e-book.h b/addressbook/libebook/e-book.h
index 64dcf5e..c2dde74 100644
--- a/addressbook/libebook/e-book.h
+++ b/addressbook/libebook/e-book.h
@@ -38,7 +38,7 @@ typedef struct _EBookPrivate EBookPrivate;
 #ifndef E_BOOK_DISABLE_DEPRECATED
 typedef void (*EBookCallback) (EBook *book, EBookStatus status, gpointer closure);
 #endif
-typedef void (*EBookExCallback) (EBook *book, const GError *error, gpointer closure);
+typedef void (*EBookAsyncCallback) (EBook *book, const GError *error, gpointer closure);
 typedef void (*EBookOpenProgressCallback)     (EBook          *book,
 					       const gchar     *status_message,
 					       short           percent,
@@ -50,11 +50,11 @@ typedef void (*EBookListCallback)     (EBook *book, EBookStatus status, GList *l
 typedef void (*EBookBookViewCallback) (EBook *book, EBookStatus status, EBookView *book_view, gpointer closure);
 typedef void (*EBookEListCallback)   (EBook *book, EBookStatus status, EList *list, gpointer closure);
 #endif
-typedef void (*EBookIdExCallback)       (EBook *book, const GError *error, const gchar *id, gpointer closure);
-typedef void (*EBookContactExCallback)  (EBook *book, const GError *error, EContact *contact, gpointer closure);
-typedef void (*EBookListExCallback)     (EBook *book, const GError *error, GList *list, gpointer closure);
-typedef void (*EBookBookViewExCallback) (EBook *book, const GError *error, EBookView *book_view, gpointer closure);
-typedef void (*EBookEListExCallback)   (EBook *book, const GError *error, EList *list, gpointer closure);
+typedef void (*EBookIdAsyncCallback)       (EBook *book, const GError *error, const gchar *id, gpointer closure);
+typedef void (*EBookContactAsyncCallback)  (EBook *book, const GError *error, EContact *contact, gpointer closure);
+typedef void (*EBookListAsyncCallback)     (EBook *book, const GError *error, GList *list, gpointer closure);
+typedef void (*EBookBookViewAsyncCallback) (EBook *book, const GError *error, EBookView *book_view, gpointer closure);
+typedef void (*EBookEListAsyncCallback)   (EBook *book, const GError *error, EList *list, gpointer closure);
 
 struct _EBook {
 	GObject       parent;
@@ -99,10 +99,10 @@ guint    e_book_async_open                 (EBook         *book,
 					    gpointer       closure);
 #endif
 
-gboolean e_book_async_open_ex              (EBook         *book,
-					    gboolean       only_if_exists,
-					    EBookExCallback  open_response,
-					    gpointer       closure);
+gboolean e_book_open_async                 (EBook              *book,
+					    gboolean            only_if_exists,
+					    EBookAsyncCallback  open_response,
+					    gpointer            closure);
 
 gboolean e_book_remove                     (EBook       *book,
 					    GError     **error);
@@ -112,9 +112,9 @@ guint    e_book_async_remove               (EBook   *book,
 					    gpointer closure);
 #endif
 
-gboolean e_book_async_remove_ex            (EBook   *book,
-					    EBookExCallback cb,
-					    gpointer closure);
+gboolean e_book_remove_async               (EBook             *book,
+					    EBookAsyncCallback cb,
+					    gpointer           closure);
 
 gboolean e_book_get_required_fields       (EBook       *book,
 					    GList      **fields,
@@ -126,9 +126,9 @@ guint    e_book_async_get_required_fields (EBook              *book,
 					    gpointer            closure);
 #endif
 
-gboolean e_book_async_get_required_fields_ex (EBook               *book,
-					      EBookEListExCallback cb,
-					      gpointer             closure);
+gboolean e_book_get_required_fields_async (EBook                  *book,
+					   EBookEListAsyncCallback cb,
+					   gpointer                closure);
 
 gboolean e_book_get_supported_fields       (EBook       *book,
 					    GList      **fields,
@@ -140,9 +140,9 @@ guint    e_book_async_get_supported_fields (EBook              *book,
 					    gpointer            closure);
 #endif
 
-gboolean e_book_async_get_supported_fields_ex (EBook               *book,
-					       EBookEListExCallback cb,
-					       gpointer             closure);
+gboolean e_book_get_supported_fields_async (EBook                  *book,
+					    EBookEListAsyncCallback cb,
+					    gpointer                closure);
 
 gboolean e_book_get_supported_auth_methods       (EBook       *book,
 						  GList      **auth_methods,
@@ -154,9 +154,9 @@ guint    e_book_async_get_supported_auth_methods (EBook              *book,
 						  gpointer            closure);
 #endif
 
-gboolean e_book_async_get_supported_auth_methods_ex (EBook               *book,
-						     EBookEListExCallback cb,
-						     gpointer             closure);
+gboolean e_book_get_supported_auth_methods_async (EBook                  *book,
+						  EBookEListAsyncCallback cb,
+						  gpointer                closure);
 
 /* User authentication. */
 gboolean e_book_authenticate_user          (EBook       *book,
@@ -174,12 +174,12 @@ guint e_book_async_authenticate_user       (EBook                 *book,
 					    gpointer              closure);
 #endif
 
-gboolean e_book_async_authenticate_user_ex (EBook                *book,
-					    const gchar          *user,
-					    const gchar          *passwd,
-					    const gchar          *auth_method,
-					    EBookExCallback       cb,
-					    gpointer              closure);
+gboolean e_book_authenticate_user_async (EBook                *book,
+					 const gchar          *user,
+					 const gchar          *passwd,
+					 const gchar          *auth_method,
+					 EBookAsyncCallback    cb,
+					 gpointer              closure);
 
 /* Fetching contacts. */
 gboolean e_book_get_contact                (EBook       *book,
@@ -194,10 +194,10 @@ guint     e_book_async_get_contact         (EBook                 *book,
 					    gpointer               closure);
 #endif
 
-gboolean  e_book_async_get_contact_ex      (EBook                 *book,
-					    const gchar           *id,
-					    EBookContactExCallback cb,
-					    gpointer               closure);
+gboolean  e_book_get_contact_async      (EBook                    *book,
+					 const gchar              *id,
+					 EBookContactAsyncCallback cb,
+					 gpointer                  closure);
 
 /* Deleting contacts. */
 gboolean e_book_remove_contact             (EBook       *book,
@@ -210,18 +210,18 @@ guint    e_book_async_remove_contact       (EBook                 *book,
 					    EBookCallback          cb,
 					    gpointer               closure);
 guint    e_book_async_remove_contact_by_id (EBook                 *book,
-					    const gchar            *id,
+					    const gchar           *id,
 					    EBookCallback          cb,
 					    gpointer               closure);
 #endif
 
-gboolean e_book_async_remove_contact_ex    (EBook                 *book,
+gboolean e_book_remove_contact_async        (EBook                *book,
 					    EContact              *contact,
-					    EBookExCallback        cb,
+					    EBookAsyncCallback     cb,
 					    gpointer               closure);
-gboolean e_book_async_remove_contact_by_id_ex (EBook              *book,
+gboolean e_book_remove_contact_by_id_async (EBook                 *book,
 					    const gchar           *id,
-					    EBookExCallback        cb,
+					    EBookAsyncCallback     cb,
 					    gpointer               closure);
 
 gboolean e_book_remove_contacts            (EBook       *book,
@@ -235,10 +235,10 @@ guint    e_book_async_remove_contacts      (EBook                 *book,
 					    gpointer               closure);
 #endif
 
-gboolean e_book_async_remove_contacts_ex   (EBook                 *book,
-					    GList                 *ids,
-					    EBookExCallback        cb,
-					    gpointer               closure);
+gboolean e_book_remove_contacts_async   (EBook                 *book,
+					 GList                 *ids,
+					 EBookAsyncCallback     cb,
+					 gpointer               closure);
 
 /* Adding contacts. */
 gboolean e_book_add_contact                (EBook           *book,
@@ -252,10 +252,10 @@ gboolean e_book_async_add_contact          (EBook           *book,
 					    gpointer         closure);
 #endif
 
-gboolean e_book_async_add_contact_ex       (EBook             *book,
-					    EContact          *contact,
-					    EBookIdExCallback  cb,
-					    gpointer           closure);
+gboolean e_book_add_contact_async       (EBook                 *book,
+					 EContact              *contact,
+					 EBookIdAsyncCallback   cb,
+					 gpointer               closure);
 
 /* Modifying contacts. */
 gboolean e_book_commit_contact             (EBook       *book,
@@ -269,10 +269,10 @@ guint e_book_async_commit_contact          (EBook                 *book,
 					    gpointer               closure);
 #endif
 
-gboolean e_book_async_commit_contact_ex    (EBook                 *book,
-					    EContact              *contact,
-					    EBookExCallback        cb,
-					    gpointer               closure);
+gboolean e_book_commit_contact_async    (EBook                 *book,
+					 EContact              *contact,
+					 EBookAsyncCallback     cb,
+					 gpointer               closure);
 
 /* Returns a live view of a query. */
 gboolean e_book_get_book_view              (EBook       *book,
@@ -291,12 +291,12 @@ guint e_book_async_get_book_view           (EBook                 *book,
 					    gpointer               closure);
 #endif
 
-gboolean e_book_async_get_book_view_ex     (EBook                  *book,
-					    EBookQuery             *query,
-					    GList                  *requested_fields,
-					    gint                    max_results,
-					    EBookBookViewExCallback cb,
-					    gpointer                closure);
+gboolean e_book_get_book_view_async     (EBook                     *book,
+					 EBookQuery                *query,
+					 GList                     *requested_fields,
+					 gint                       max_results,
+					 EBookBookViewAsyncCallback cb,
+					 gpointer                   closure);
 
 /* Returns a static snapshot of a query. */
 gboolean e_book_get_contacts               (EBook       *book,
@@ -311,10 +311,10 @@ guint     e_book_async_get_contacts        (EBook             *book,
 					    gpointer           closure);
 #endif
 
-gboolean  e_book_async_get_contacts_ex     (EBook              *book,
-					    EBookQuery         *query,
-					    EBookListExCallback cb,
-					    gpointer            closure);
+gboolean  e_book_get_contacts_async     (EBook                 *book,
+					 EBookQuery            *query,
+					 EBookListAsyncCallback cb,
+					 gpointer               closure);
 
 /* Needed for syncing */
 gboolean e_book_get_changes                (EBook       *book,
@@ -329,10 +329,10 @@ guint    e_book_async_get_changes          (EBook             *book,
 					    gpointer           closure);
 #endif
 
-gboolean e_book_async_get_changes_ex       (EBook              *book,
-					    const gchar        *changeid,
-					    EBookListExCallback cb,
-					    gpointer            closure);
+gboolean e_book_get_changes_async       (EBook                 *book,
+					 const gchar           *changeid,
+					 EBookListAsyncCallback cb,
+					 gpointer               closure);
 
 void     e_book_free_change_list           (GList       *change_list);
 
diff --git a/addressbook/tests/ebook/ebook-test-utils.c b/addressbook/tests/ebook/ebook-test-utils.c
index fa021b6..12045fe 100644
--- a/addressbook/tests/ebook/ebook-test-utils.c
+++ b/addressbook/tests/ebook/ebook-test-utils.c
@@ -160,8 +160,8 @@ ebook_test_utils_book_async_add_contact (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_add_contact_ex (book, contact,
-                                (EBookIdExCallback) add_contact_cb, closure)) {
+        if (!e_book_add_contact_async (book, contact,
+                                (EBookIdAsyncCallback) add_contact_cb, closure)) {
                 g_warning ("failed to set up contact add");
                 exit(1);
         }
@@ -215,8 +215,8 @@ ebook_test_utils_book_async_commit_contact (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_commit_contact_ex (book, contact,
-                                (EBookExCallback) commit_contact_cb, closure)) {
+        if (!e_book_commit_contact_async (book, contact,
+                                (EBookAsyncCallback) commit_contact_cb, closure)) {
                 g_warning ("failed to set up contact commit");
                 exit(1);
         }
@@ -276,8 +276,8 @@ ebook_test_utils_book_async_get_contact (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_get_contact_ex (book, uid,
-                                (EBookContactExCallback) get_contact_cb,
+        if (!e_book_get_contact_async (book, uid,
+                                (EBookContactAsyncCallback) get_contact_cb,
                                 closure)) {
                 g_warning ("failed to set up async getContact");
                 exit(1);
@@ -334,8 +334,8 @@ ebook_test_utils_book_async_get_required_fields (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_get_required_fields_ex (book,
-                                (EBookEListExCallback) get_required_fields_cb,
+        if (!e_book_get_required_fields_async (book,
+                                (EBookEListAsyncCallback) get_required_fields_cb,
                                 closure)) {
                 g_warning ("failed to set up async getRequiredFields");
                 exit(1);
@@ -411,8 +411,8 @@ ebook_test_utils_book_async_get_supported_auth_methods (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_get_supported_auth_methods_ex (book,
-                                (EBookEListExCallback) get_supported_auth_methods_cb,
+        if (!e_book_get_supported_auth_methods_async (book,
+                                (EBookEListAsyncCallback) get_supported_auth_methods_cb,
                                 closure)) {
                 g_warning ("failed to set up async getSupportedAuthMethods");
                 exit(1);
@@ -469,8 +469,8 @@ ebook_test_utils_book_async_get_supported_fields (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_get_supported_fields_ex (book,
-                                (EBookEListExCallback) get_supported_fields_cb,
+        if (!e_book_get_supported_fields_async (book,
+                                (EBookEListAsyncCallback) get_supported_fields_cb,
                                 closure)) {
                 g_warning ("failed to set up async getSupportedFields");
                 exit(1);
@@ -523,8 +523,8 @@ ebook_test_utils_book_async_remove_contact (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_remove_contact_ex (book, contact,
-                                (EBookExCallback) remove_contact_cb,
+        if (!e_book_remove_contact_async (book, contact,
+                                (EBookAsyncCallback) remove_contact_cb,
                                 closure)) {
                 g_warning ("failed to set up async removeContacts (for a single contact)");
                 exit(1);
@@ -561,8 +561,8 @@ ebook_test_utils_book_async_remove_contact_by_id (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_remove_contact_by_id_ex (book, uid,
-                                (EBookExCallback) remove_contact_by_id_cb,
+        if (!e_book_remove_contact_by_id_async (book, uid,
+                                (EBookAsyncCallback) remove_contact_by_id_cb,
                                 closure)) {
                 g_warning ("failed to set up async removeContacts (by id)");
                 exit(1);
@@ -615,8 +615,8 @@ ebook_test_utils_book_async_remove_contacts (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_remove_contacts_ex (book, uids,
-                                (EBookExCallback) remove_contacts_cb,
+        if (!e_book_remove_contacts_async (book, uids,
+                                (EBookAsyncCallback) remove_contacts_cb,
                                 closure)) {
                 g_warning ("failed to set up async removeContacts");
                 exit(1);
@@ -723,7 +723,7 @@ ebook_test_utils_book_async_remove (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_remove_ex (book, (EBookExCallback) remove_cb, closure)) {
+        if (!e_book_remove_async (book, (EBookAsyncCallback) remove_cb, closure)) {
                 g_warning ("failed to set up book removal");
                 exit(1);
         }
@@ -777,7 +777,7 @@ ebook_test_utils_book_async_get_book_view (EBook       *book,
         closure = g_new0 (EBookTestClosure, 1);
         closure->cb = callback;
         closure->user_data = user_data;
-        if (!e_book_async_get_book_view_ex (book, query, NULL, -1, (EBookBookViewExCallback) get_book_view_cb, closure)) {
+        if (!e_book_get_book_view_async (book, query, NULL, -1, (EBookBookViewAsyncCallback) get_book_view_cb, closure)) {
                 g_warning ("failed to set up book view retrieval");
                 exit(1);
         }
diff --git a/addressbook/tests/ebook/test-ebook-async.c b/addressbook/tests/ebook/test-ebook-async.c
index 813d008..902892d 100644
--- a/addressbook/tests/ebook/test-ebook-async.c
+++ b/addressbook/tests/ebook/test-ebook-async.c
@@ -50,7 +50,7 @@ print_all_emails (EBook *book)
 
 	query = e_book_query_field_exists (E_CONTACT_FULL_NAME);
 
-	e_book_async_get_contacts_ex (book, query, print_all_emails_cb, NULL);
+	e_book_get_contacts_async (book, query, print_all_emails_cb, NULL);
 
 	e_book_query_unref (query);
 }
@@ -70,7 +70,7 @@ print_email_cb (EBook *book, const GError *error, EContact *contact, gpointer cl
 static void
 print_one_email (EBook *book)
 {
-	e_book_async_get_contact_ex (book, "pas-id-0002023", print_email_cb, NULL);
+	e_book_get_contact_async (book, "pas-id-0002023", print_email_cb, NULL);
 }
 
 static void
@@ -100,7 +100,7 @@ main (gint argc, gchar **argv)
 	book = e_book_new_system_addressbook (NULL);
 
 	printf ("loading addressbook\n");
-	e_book_async_open_ex (book, FALSE, book_loaded_cb, book);
+	e_book_open_async (book, FALSE, book_loaded_cb, book);
 
 	g_main_loop_run (loop);
 
diff --git a/libedataserverui/e-book-auth-util.h b/libedataserverui/e-book-auth-util.h
index 4401cf7..893991e 100644
--- a/libedataserverui/e-book-auth-util.h
+++ b/libedataserverui/e-book-auth-util.h
@@ -32,6 +32,6 @@
 EBook *e_load_book_source (ESource *source, EBookCallback open_func, gpointer user_data);
 #endif
 
-EBook *e_load_book_source_ex (ESource *source, EBookExCallback open_func, gpointer user_data);
+EBook *e_load_book_source_async (ESource *source, EBookAsyncCallback open_func, gpointer user_data);
 
 #endif
diff --git a/libedataserverui/e-name-selector-dialog.c b/libedataserverui/e-name-selector-dialog.c
index 402bd24..88fe902 100644
--- a/libedataserverui/e-name-selector-dialog.c
+++ b/libedataserverui/e-name-selector-dialog.c
@@ -820,7 +820,7 @@ source_changed (ENameSelectorDialog *name_selector_dialog,
 	remove_books (name_selector_dialog);
 
 	/* Start loading selected book */
-	name_selector_dialog->priv->pending_book = e_load_book_source_ex (
+	name_selector_dialog->priv->pending_book = e_load_book_source_async (
 		source, book_opened, name_selector_dialog);
 }
 
diff --git a/libedataserverui/e-name-selector-entry.c b/libedataserverui/e-name-selector-entry.c
index 59ace12..c3a1910 100644
--- a/libedataserverui/e-name-selector-entry.c
+++ b/libedataserverui/e-name-selector-entry.c
@@ -1948,7 +1948,7 @@ setup_default_contact_store (ENameSelectorEntry *name_selector_entry)
 			if (!completion || g_ascii_strcasecmp (completion, "true"))
 				continue;
 
-			book = e_load_book_source_ex (source, NULL, NULL);
+			book = e_load_book_source_async (source, NULL, NULL);
 			if (!book)
 				continue;
 
diff --git a/libedataserverui/e-name-selector.c b/libedataserverui/e-name-selector.c
index 725fe82..823dedd 100644
--- a/libedataserverui/e-name-selector.c
+++ b/libedataserverui/e-name-selector.c
@@ -101,7 +101,7 @@ load_books_thread (gpointer user_data)
 			if (!completion || g_ascii_strcasecmp (completion, "true"))
 				continue;
 
-			source_book.book = e_load_book_source_ex (source, NULL, NULL);
+			source_book.book = e_load_book_source_async (source, NULL, NULL);
 			if (!source_book.book)
 				continue;
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libedataserverui/e-book-auth-util.c b/libedataserverui/e-book-auth-util.c
index 485de2a..64c1352 100644
--- a/libedataserverui/e-book-auth-util.c
+++ b/libedataserverui/e-book-auth-util.c
@@ -33,7 +33,7 @@
 #include "e-book-auth-util.h"
 
 static void addressbook_authenticate (EBook *book, gboolean previous_failure,
-				      ESource *source, EBookExCallback cb, gpointer closure);
+				      ESource *source, EBookAsyncCallback cb, gpointer closure);
 static void auth_required_cb (EBook *book, gpointer data);
 typedef struct {
 	ESource       *source;
@@ -42,7 +42,7 @@ typedef struct {
 	#ifndef E_BOOK_DISABLE_DEPRECATED
 	EBookCallback  open_func;
 	#endif
-	EBookExCallback  open_func_ex;
+	EBookAsyncCallback  open_func_ex;
 	gpointer       open_func_data;
 } LoadSourceData;
 
@@ -156,7 +156,7 @@ set_remember_password (ESource *source, gboolean value)
 
 static void
 addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *source,
-			  EBookExCallback cb, gpointer closure)
+			  EBookAsyncCallback cb, gpointer closure)
 {
 	const gchar *auth;
 	const gchar *user;
@@ -220,7 +220,7 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 	}
 
 	if (password) {
-		e_book_async_authenticate_user_ex (book, user, password,
+		e_book_authenticate_user_async (book, user, password,
 						e_source_get_property (source, "auth"),
 						cb, closure);
 		g_free (password);
@@ -295,7 +295,7 @@ load_source_cb (EBook *book, const GError *error, gpointer closure)
  *
  * Returns: A new #EBook that is being opened.
  *
  * Deprecated: 3.0: Use e_load_book_source_ex() instead.
  **/
 EBook *
 e_load_book_source (ESource *source, EBookCallback open_func, gpointer user_data)
@@ -313,13 +313,13 @@ e_load_book_source (ESource *source, EBookCallback open_func, gpointer user_data
 
 	load_source_data->book = book;
 	g_object_ref (book);
-	e_book_async_open_ex (book, FALSE, load_source_cb, load_source_data);
+	e_book_open_async (book, FALSE, load_source_cb, load_source_data);
 	return book;
 }
 #endif
 
 /**
- * e_load_book_source_ex:
+ * e_load_book_source_async:
  * @source: an #ESource
  * @open_func_ex: a function to call when the operation finishes, or %NULL
  * @user_data: data to pass to callback function
@@ -337,7 +337,7 @@ e_load_book_source (ESource *source, EBookCallback open_func, gpointer user_data
  * Since: 3.0
  **/
 EBook *
-e_load_book_source_ex (ESource *source, EBookExCallback open_func_ex, gpointer user_data)
+e_load_book_source_async (ESource *source, EBookAsyncCallback open_func_ex, gpointer user_data)
 {
 	EBook          *book;
 	LoadSourceData *load_source_data = g_new0 (LoadSourceData, 1);
@@ -352,7 +352,7 @@ e_load_book_source_ex (ESource *source, EBookExCallback open_func_ex, gpointer u
 
 	load_source_data->book = book;
 	g_object_ref (book);
-	e_book_async_open_ex (book, FALSE, load_source_cb, load_source_data);
+	e_book_open_async (book, FALSE, load_source_cb, load_source_data);
 
 	return book;
 }
@@ -295,7 +295,7 @@ load_source_cb (EBook *book, const GError *error, gpointer closure)
  * Returns: A new #EBook that is being opened.
  *
- * Deprecated: 3.0: Use e_load_book_source_ex() instead.
+ * Deprecated: 3.0: Use e_load_book_source_async() instead.
  **/
 EBook *